@@ -65,8 +65,9 @@ class ConfuseCallback(tf.keras.callbacks.Callback):
             for b in range(0, self.x_test.shape[0], self.batch_size):
                 x_feed = self.x_test[b:b+self.batch_size]
                 pred = self.model.predict(x_feed)
+                pred = np.argmax(pred, axis=1)
                 test_pred = np.concatenate([test_pred, pred])
-            test_pred = tf.argmax(test_pred, axis=1)
+
             accuracy = np.sum(test_pred == self.y_test) / self.y_test.shape[0]
 
             con_mat = tf.math.confusion_matrix(labels=self.y_test, predictions=test_pred).numpy()
